==> fillets-ng-data_0.7.1.orig.tar.gz: fillets-ng-data-0.7.1/script/cave/dialogs_it.lua <==

dialogId("jes-m-netopyr", "font_small", "That bat must be terribly strong.")
dialogStr("Quel pipistrello dev'essere terribilmente forzuto.")

dialogId("jes-v-tojo", "font_big", "Well, yes.")
dialogStr("Mmm... già.")

dialogId("jes-m-tvor", "font_small", "That red creature is a little bit strange.")
dialogStr("Quella creatura rossa è un po' strana.")

dialogId("jes-v-nestezuj", "font_big", "That may be true, but I think we are going to need it.")
dialogStr("Poù darsi. Comunque credo che ne avremo bisogno.")

dialogId("jes-v-uzke", "font_big", "It`s too narrow for me. You have to do it on your own down there.")
dialogStr("È troppo stretto per me. Dovrai occupartene da sola, là sotto.")

dialogId("jes-m-ryba", "font_small", "That white fish is a terrible obstacle.")
dialogStr("Quel pesciolino bianco è incredibilmente d'ostacolo.")

dialogId("jes-v-kamen", "font_big", "Fish? I thought it was only a stone.")
dialogStr("Pesce? Pensavo che fosse semplicemente una pietra.")

dialogId("jes-v-gral", "font_big", "I think that we should be looking for the Grail somewhere else...")
dialogStr("Penso che dovremmo cercare il Graal da qualche altra parte...")

dialogId("jes-m-deprese", "font_small", "Don`t be depressive. We will solve this in no time.")
dialogStr("Non deprimerti. Lo risolveremo in un battibaleno.")

dialogId("jes-v-nevim", "font_big", "I am not so sure.")
dialogStr("Non saprei...")

dialogId("jes-m-takvidis", "font_small", "See? You are here.")
dialogStr("Vedi? sei qui.")

dialogId("jes-m-potvora0", "font_small", "What kind of color-shifting monster is this?")
dialogStr("Che razza di mostro mimetico è questo?")

dialogId("jes-m-potvora1", "font_small", "This is an abomination.")
dialogStr("È abominevole.")

dialogId("jes-m-potvora2", "font_small", "This is an offense of Nature.")
dialogStr("È uno scherzo della natura.")

dialogId("jes-v-potvora0", "font_big", "It is called the Flashy hammerhead.")
dialogStr("È conosciuto come Pesce martello chiassoso.")

dialogId("jes-v-potvora1", "font_big", "It is called the Glossy repulsor.")
dialogStr("È conosciuto come Repulsore lucido.")

dialogId("jes-v-potvora2", "font_big", "It is called the Politician fish.")
dialogStr("È conosciuto come Pesce politico.")

dialogId("jes-m-netopyr0", "font_small", "This bat is kind of strange.")
dialogStr("Questo pipistrello è piuttosto strano.")

dialogId("jes-v-netopyr0", "font_big", "This is very phlegmatic bat.")
dialogStr("È un pipistrello molto flemmatico.")

dialogId("jes-m-netopyr1", "font_small", "This is a stuffed bat.")
dialogStr("È un pipistrello imbottito.")

dialogId("jes-v-netopyr1", "font_big", "It`s a sculpture of bat.")
dialogStr("È la scultura di un pipistrello.")

dialogId("jes-m-netopyr2", "font_small", "It`s a stalagmite shaped as a bat.")
dialogStr("È una stalagmite a forma di pipistrello.")

dialogId("jes-v-netopyr2", "font_big", "It`s a plain stalagmite.")
dialogStr("È una normale stalagmite.")

dialogId("jes-m-netopyr3", "font_small", "It`s just an ordinary piece of rock.")
dialogStr("È solo un pezzo di roccia qualsiasi.")

dialogId("jes-v-nechut0", "font_big", "I think you are going to need that 'monster`.")
dialogStr("Penso che avrai bisogno di quel `mostro'.")

dialogId("jes-v-nechut1", "font_big", "I think you will have to overcome your dislike of that 'abomination`.")
dialogStr("Penso che dovrai vincere la tua avversione per quell'`abominio'.")

==> fillets-ng-data_0.8.0.orig.tar.gz: fillets-ng-data-0.8.0/script/cave/dialogs_it.lua <==

dialogId("jes-m-netopyr", "font_small", "That bat must be terribly strong.")
dialogStr("Quel pipistrello dev'essere terribilmente forzuto.")

dialogId("jes-v-tojo", "font_big", "Well, yes.")
dialogStr("Mmm... già.")

dialogId("jes-m-tvor", "font_small", "That red creature is a little bit strange.")
dialogStr("Quella creatura rossa è un po' strana.")

dialogId("jes-v-nestezuj", "font_big", "That may be true, but I think we are going to need it.")
dialogStr("Poù darsi. Comunque credo che ne avremo bisogno.")

dialogId("jes-v-uzke", "font_big", "It’s too narrow for me. You have to do it on your own down there.")
dialogStr("È troppo stretto per me. Dovrai occupartene da sola, là sotto.")

dialogId("jes-m-ryba", "font_small", "That white fish is a terrible obstacle.")
dialogStr("Quel pesciolino bianco è incredibilmente d'ostacolo.")

dialogId("jes-v-kamen", "font_big", "Fish? I thought it was only a stone.")
dialogStr("Pesce? Pensavo che fosse semplicemente una pietra.")

dialogId("jes-v-gral", "font_big", "I think that we should be looking for the Grail somewhere else...")
dialogStr("Penso che dovremmo cercare il Graal da qualche altra parte...")

dialogId("jes-m-deprese", "font_small", "Don’t be depressive. We will solve this in no time.")
dialogStr("Non deprimerti. Lo risolveremo in un battibaleno.")

dialogId("jes-v-nevim", "font_big", "I am not so sure.")
dialogStr("Non saprei...")

dialogId("jes-m-takvidis", "font_small", "See? You are here.")
dialogStr("Vedi? sei qui.")

dialogId("jes-m-potvora0", "font_small", "What kind of color-shifting monster is this?")
dialogStr("Che razza di mostro mimetico è questo?")

dialogId("jes-m-potvora1", "font_small", "This is an abomination.")
dialogStr("È abominevole.")

dialogId("jes-m-potvora2", "font_small", "This is an offense of Nature.")
dialogStr("È uno scherzo della natura.")

dialogId("jes-v-potvora0", "font_big", "It is called the Flashy hammerhead.")
dialogStr("È conosciuto come Pesce martello chiassoso.")

dialogId("jes-v-potvora1", "font_big", "It is called the Glossy repulsor.")
dialogStr("È conosciuto come Repulsore lucido.")

dialogId("jes-v-potvora2", "font_big", "It is called the Politician fish.")
dialogStr("È conosciuto come Pesce politico.")

dialogId("jes-m-netopyr0", "font_small", "This bat is kind of strange.")
dialogStr("Questo pipistrello è piuttosto strano.")

dialogId("jes-v-netopyr0", "font_big", "This is very phlegmatic bat.")
dialogStr("È un pipistrello molto flemmatico.")

dialogId("jes-m-netopyr1", "font_small", "This is a stuffed bat.")
dialogStr("È un pipistrello imbottito.")

dialogId("jes-v-netopyr1", "font_big", "It’s a sculpture of bat.")
dialogStr("È la scultura di un pipistrello.")

dialogId("jes-m-netopyr2", "font_small", "It’s a stalagmite shaped as a bat.")
dialogStr("È una stalagmite a forma di pipistrello.")

dialogId("jes-v-netopyr2", "font_big", "It’s a plain stalagmite.")
dialogStr("È una normale stalagmite.")

dialogId("jes-m-netopyr3", "font_small", "It’s just an ordinary piece of rock.")
dialogStr("È solo un pezzo di roccia qualsiasi.")

dialogId("jes-v-nechut0", "font_big", "I think you are going to need that 'monster’.")
dialogStr("Penso che avrai bisogno di quel ’mostro'.")

dialogId("jes-v-nechut1", "font_big", "I think you will have to overcome your dislike of that 'abomination’.")
dialogStr("Penso che dovrai vincere la tua avversione per quell'’abominio'.")
